@@ -2,12 +2,12 @@ package Hades::Realm::OO;
 use strict;
 use warnings;
 use base qw/Hades/;
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
 	my $self      = $cls->SUPER::new(%args);
-	my %accessors = ( is_role => {}, meta => {}, current_class => {}, );
+	my %accessors = ( current_class => {}, meta => {}, is_role => {}, );
 	for my $accessor ( keys %accessors ) {
 		my $param
 		    = defined $args{$accessor}
@@ -172,7 +172,7 @@ sub build_class_inheritance {
 		return 'extends' if $1 =~ m/parent|base/;
 		return $params[-1];
 	}
-	elsif ( $params[2] && $params[-2] =~ m/^(with|extends)$/ ) {
+	elsif ( $params[-2] && $params[-2] =~ m/^(with|extends)$/ ) {
 		my ( $mg, $last, $ident ) = splice @params, -3;
 		$mg->$last($ident);
 		return $last;
